==> cmsmadesimple-1.6.6.tgz: cms/modules/FileManager/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'Bestandsbeheer ';
$lang['permission'] = 'Gebruik van de Bestandsbeheer-module';
$lang['permissionadvanced'] = 'Gevorderd gebruik van de Bestandsbeheer-module';
$lang['moddescription'] = 'Beheer van bestanden en mappen in de Uploads-map';
$lang['installed'] = 'File Manager versie %s ge&iuml;nstalleerd';
$lang['postinstall'] = 'File Manager-module is ge&iuml;nstalleerd';
$lang['uninstalled'] = 'File Manager-module gede&iuml;nstalleerd';
$lang['really_uninstall'] = 'Weet u zeker dat de File Manager-module gede&iuml;nstalleerd moet worden';
$lang['upgraded'] = 'File Manager-module is upgraded naar versie %s';
$lang['fileview'] = 'Bestandsweergave';
$lang['switchtofileview'] = 'Schakel naar bestandsweergave';
$lang['settings'] = 'Instellingen';
$lang['savesettings'] = 'Bewaar instellingen';
$lang['filename'] = 'Bestandsnaam';
$lang['fileinfo'] = 'Bestandsinformatie';
$lang['fileowner'] = 'Bestandseigenaar';
$lang['fileperms'] = 'Rechten';
$lang['filesize'] = 'Grootte';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Acties';
$lang['delete'] = 'Verwijder';
$lang['notwritable'] = 'Niet schrijfbaar';
$lang['filetoobig'] = 'is te groot. Upload is afgebroken.';
$lang['unknown'] = 'Onbekend';
$lang['fileoutsideuploads'] = 'U heef geen autorisatie om bestanden buiten de uploads-folder aan te passen! (Daarvoor is Advanced File Management permissie nodig)';
$lang['writable'] = 'Schrijfbaar';
$lang['writeprotected'] = 'Schrijf beveiligd';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'bestanden';
$lang['bytesin'] = 'bytes in ';
$lang['in'] = 'in ';
$lang['file'] = 'bestand';
$lang['fileno'] = 'Bestandsnr.';
$lang['subdirs'] = 'submappen';
$lang['subdir'] = 'submap';
$lang['and'] = 'en';
$lang['confirmsingledelete'] = 'Weet u het zeker?';
$lang['confirmsingledirdelete'] = 'Weet u zeker dat deze map verwijderd moet worden?';
$lang['dirtreedeletesuccess'] = 'De map en de inhoud is verwijderd.';
$lang['dirtreedeletefail'] = 'Er is een fout opgetreden bij het verwijderen van deze map. Een deel van de inhoud kan echter verwijderd zijn.';
$lang['singlefiledeletesuccess'] = 'Het bestand is verwijderd';
$lang['filedeletesuccess'] = 'is verwijderd';
$lang['singlefiledeletefail'] = 'Er is een fout opgetreden bij het verwijderen van het bestand';
$lang['filedeletefail'] = ' is vanwege een fout niet verwijderd';
$lang['singledirdeletesuccess'] = 'De map is verwijderd';
$lang['singledirdeletefail'] = 'Een fout is opgetreden bij het verwijderen van de map (is deze leeg?)';
$lang['deleteselected'] = 'Verwijder de geselecteerde bestanden';
$lang['confirmselected'] = 'Weet u het zeker?';
$lang['confirmdeleteselected'] = 'Weet u zeker dat de geselecteerde bestanden moeten worden verwijderd?';
$lang['deleteselectedcancelled'] = 'Verwijderen van geselecteerde bestanden geannuleerd';
$lang['recursetext'] = 'Recursief in mappen';
$lang['nofilesselected'] = 'Geen bestanden geselecteerd';
$lang['moveselected'] = 'Verplaats de geselecteerde bestanden';
$lang['copyselected'] = 'Kopieer de geselecteerde bestanden';
$lang['selecttargetdir'] = 'Selecteer de doel-directory voor het verplaatsen/kopieren';
$lang['movedto'] = 'verplaatst naar';
$lang['copiedto'] = 'gekopieerd naar';
$lang['couldnotmove'] = 'kon niet worden verplaatst';
$lang['couldnotcopy'] = 'kon niet worden gekopieerd';
$lang['rename'] = 'Naam wijzigen';
$lang['newname'] = 'Nieuwe naam:';
$lang['renamesuccess'] = 'Bestandsnaam gewijzigd';
$lang['renamefailure'] = 'Naam wijzigen mislukt';
$lang['renamecancelled'] = 'Naam wijzigen geannuleerd';
$lang['owner'] = 'Eigenaar';
$lang['group'] = 'Groep';
$lang['others'] = 'Overigen';
$lang['newpermissions'] = 'Nieuwe permissies:';
$lang['setpermissions'] = 'Plaats permissies';
$lang['permissionstyle'] = 'Permissie stijl';
$lang['rwxstyle'] = 'rwx stijl ';
$lang['755style'] = '755 stijl ';
$lang['quickmode'] = 'Snelle chmod (zoals 777)';
$lang['chmod'] = 'Wijzig permissies';
$lang['chmodselected'] = 'Wijzig permissies op geselecteerde bestanden';
$lang['chmodsuccess'] = 'Permissies gewijzigd';
$lang['chmodfailure'] = 'Permissies wijzigen mislukt';
$lang['chmodcancelled'] = 'Permissies wijzigen geannuleerd';
$lang['dirchmodfailmulti'] = 'Permissie wijzigen van deze map is mislukt, het kan echter wel zijn dat bepaalde bestanden wel gewijzigde rechten hebben gekregen.';
$lang['dirchmodsuccessmulti'] = 'Permissies wijzigen van de map en de inhoud is geslaagd';
$lang['dirchmodsuccess'] = 'Map permissies gewijzigd';
$lang['dirchmodfailure'] = 'Map permissies wijzigen mislukt';
$lang['dirnotemptyconfirm'] = 'Deze map is niet leeg. Weet u zeker dat deze verwijderd moet worden en alle inhoud, inclusief de submappen?';
$lang['dirtreedeletecancelled'] = 'Verwijdering van de map afgebroken';
$lang['imsure'] = 'Ik weet het zeker';
$lang['cancel'] = 'Annuleer';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Upload nieuwe bestanden:';
$lang['unpackafterupload'] = 'Probeer het bestand na upload, uit te pakken (alleen tgz en meeste zip-bestanden)?';
$lang['uploadsuccess'] = 'is ge&uuml;pload';
$lang['uploadfail'] = 'upload niet geslaagd';
$lang['unpacksuccess'] = 'is uitgepakt';
$lang['unpackfail'] = 'afgebroken met deze fout:';
$lang['packfileopenfail'] = 'Kon het ingepakte bestand niet openen om uit te pakken (niet-ondersteund formaat?)';
$lang['packfilewritefail'] = 'Kan het bestand %s niet openen om naar te schrijven';
$lang['currentpath'] = 'Huidig pad:';
$lang['newdirname'] = 'Maak nieuwe map aan:';
$lang['newdirsuccess'] = 'De map is aangemaakt';
$lang['newdirfail'] = 'Er is een fout opgetreden bij het aanmaken van de map';
$lang['invalidnewdir'] = 'Naam van de nieuwe map geen karakters zoals /, \ en &#039;..&#039; bevatten';
$lang['filedateformat'] = 'm/d/J U:m:s';
$lang['iconsize'] = 'Pictogramgrootte';
$lang['smallicons'] = 'Kleine pictogrammen';
$lang['largeicons'] = 'Grote pictogrammen';
$lang['thousanddelimiter'] = 'Duizendtal scheidingsteken';
$lang['none'] = 'Geen';
$lang['space'] = 'ruimte';
$lang['showthumbnails'] = 'Toon miniaturen';
$lang['showthumbnailshelp'] = 'Activeren zorgt dat er miniaturen worden getoond van afbeeldingen, wanneer deze aanwezig zijn en zal ook het miniatuur-bestand zelf  verbergen. Deactiveren zorgt ervoor dat alle bestanden worden getoond.';
$lang['uploadfilesto'] = 'Upload bestanden naar: ';
$lang['uploadview'] = 'Upload bestanden';
$lang['uploadboxes'] = 'Aantal uploadvelden';
$lang['nothinguploaded'] = 'Niets ge&uuml;pload';
$lang['unsupportedarchive'] = 'Niet-ondersteund archiefformaat';
$lang['uploadmethod'] = 'Upload-methode';
$lang['uploaderstandard'] = 'Standaard html invoermethode (staat uitpakken toe)';
$lang['enableadvanced'] = 'Sta gevorderdenmodus toe?';
$lang['advancedhelp'] = 'Geeft u toegang tot het gehele CMSMS bestandssysteem, niet alleen /uploads/ (indien toegestaan)';
$lang['showhiddenfileshelp'] = 'Alleen effectief in de gevorderenmodus';
$lang['showhiddenfiles'] = 'Toon verborgen bestanden';
$lang['settingsconfirmsingledelete'] = 'Bevestig verwijdering van een enkel bestand?';
$lang['settingssaved'] = 'Instellingen opgeslagen';
$lang['help'] = '		<h3>Wat doet het?</h3>
		<p>Deze module verzorgt een bestandsbeheer functionaliteit</p>
		<h3>Hoe gebruikt u het</h3>
		<p>Selecteer Bestandsbeheer in het Inhoudsmenu.</p>';
$lang['utma'] = '156861353.1102358534.1252830695.1253555343.1253609589.34';
$lang['utmz'] = '156861353.1253452193.26.10.utmccn=(referral)|utmcsr=zeijennu.tjassens.eu|utmcct=/admin/editevent.php|utmcmd=referral';
$lang['qca'] = 'P0-1787501767-1252830695602';
$lang['utmb'] = '156861353.5.10.1253609589';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.9.4p1.tgz: cms/modules/FileManager/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'Bestandsbeheer ';
$lang['permission'] = 'Gebruik van de Bestandsbeheer-module';
$lang['permissionadvanced'] = 'Gevorderd gebruik van de Bestandsbeheer-module';
$lang['moddescription'] = 'Beheer van bestanden en mappen in de Uploads-map';
$lang['installed'] = 'File Manager versie %s ge&iuml;nstalleerd';
$lang['postinstall'] = 'File Manager-module is ge&iuml;nstalleerd';
$lang['uninstalled'] = 'File Manager-module gede&iuml;nstalleerd';
$lang['really_uninstall'] = 'Weet u zeker dat de File Manager-module gede&iuml;nstalleerd moet worden';
$lang['upgraded'] = 'File Manager-module is bijgewerkt naar versie %s';
$lang['fileview'] = 'Bestandsweergave';
$lang['switchtofileview'] = 'Schakel naar bestandsweergave';
$lang['settings'] = 'Instellingen';
$lang['savesettings'] = 'Bewaar instellingen';
$lang['postletexists'] = 'Waarschuwing! Verwijder de servermap modules/FileManager/postlet in zijn geheel. De map en inhoud wordt al geruime tijd niet meer gebruikt en onderhouden.';
$lang['filename'] = 'Bestandsnaam';
$lang['fileinfo'] = 'Bestandsinformatie';
$lang['fileowner'] = 'Bestandseigenaar';
$lang['fileperms'] = 'Rechten';
$lang['filesize'] = 'Grootte';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Acties';
$lang['delete'] = 'Verwijder';
$lang['notwritable'] = 'Niet schrijfbaar';
$lang['afileistoobig'] = 'Een bestand is te groot. Upload is geannuleerd.';
$lang['unknown'] = 'Onbekend';
$lang['fileoutsideuploads'] = 'U heef geen autorisatie om bestanden buiten de uploads-folder aan te passen! (Daarvoor is Advanced File Management permissie nodig)';
$lang['writable'] = 'Schrijfbaar';
$lang['writeprotected'] = 'Schrijf beveiligd';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'bestanden';
$lang['bytesin'] = 'bytes in ';
$lang['in'] = 'in ';
$lang['file'] = 'bestand';
$lang['fileno'] = 'Bestandsnr.';
$lang['subdirs'] = 'submappen';
$lang['subdir'] = 'submap';
$lang['and'] = 'en';
$lang['confirmsingledelete'] = 'Weet u het zeker?';
$lang['confirmsingledirdelete'] = 'Weet u zeker dat deze map verwijderd moet worden?';
$lang['dirtreedeletesuccess'] = 'De map en de inhoud is verwijderd.';
$lang['dirtreedeletefail'] = 'Er is een fout opgetreden bij het verwijderen van deze map. Een deel van de inhoud kan echter verwijderd zijn.';
$lang['singlefiledeletesuccess'] = 'Het bestand is verwijderd';
$lang['filedeletesuccess'] = 'is verwijderd';
$lang['singlefiledeletefail'] = 'Er is een fout opgetreden bij het verwijderen van het bestand';
$lang['filedeletefail'] = ' is vanwege een fout niet verwijderd';
$lang['singledirdeletesuccess'] = 'De map is verwijderd';
$lang['singledirdeletefail'] = 'Een fout is opgetreden bij het verwijderen van de map (is deze leeg?)';
$lang['deleteselected'] = 'Verwijder de geselecteerde bestanden';
$lang['confirmselected'] = 'Weet u het zeker?';
$lang['confirmdeleteselected'] = 'Weet u zeker dat de geselecteerde bestanden moeten worden verwijderd?';
$lang['deleteselectedcancelled'] = 'Verwijderen van geselecteerde bestanden geannuleerd';
$lang['recursetext'] = 'Recursief in mappen';
$lang['nofilesselected'] = 'Geen bestanden geselecteerd';
$lang['moveselected'] = 'Verplaats de geselecteerde bestanden';
$lang['copyselected'] = 'Kopieer de geselecteerde bestanden';
$lang['selecttargetdir'] = 'Selecteer de doel-directory voor het verplaatsen/kopieren';
$lang['movedto'] = 'verplaatst naar';
$lang['copiedto'] = 'gekopieerd naar';
$lang['couldnotmove'] = 'kon niet worden verplaatst';
$lang['couldnotcopy'] = 'kon niet worden gekopieerd';
$lang['filesdeletedsuccessfully'] = '%s bestand(en) is/zijn verwijderd';
$lang['filesdeletedfiled'] = '%s bestand(en) is/zijn NIET verwijderd';
$lang['filesmovedsuccessfully'] = '%s bestand(en) is/zijn verplaatst';
$lang['filesmovedfailed'] = '%s bestand(en) is/zijn NIET verplaatst';
$lang['filescopiedsuccessfully'] = '%s bestand(en) is/zijn gekopieerd';
$lang['filescopiedfailed'] = '%s bestand(en) is/zijn NIET gekopieerd';
$lang['internalerror'] = 'Interne Fout (Geeft u ons alstublieft in een bugreport door welke stappen u heeft ondernomen dat leidde tot deze melding...)';
$lang['rename'] = 'Naam wijzigen';
$lang['newname'] = 'Nieuwe naam:';
$lang['renamesuccess'] = 'Bestandsnaam gewijzigd';
$lang['renamefailure'] = 'Naam wijzigen mislukt';
$lang['renamecancelled'] = 'Naam wijzigen geannuleerd';
$lang['owner'] = 'Eigenaar';
$lang['group'] = 'Groep';
$lang['others'] = 'Overigen';
$lang['newpermissions'] = 'Nieuwe permissies:';
$lang['setpermissions'] = 'Plaats permissies';
$lang['permissionstyle'] = 'Permissie stijl';
$lang['rwxstyle'] = 'rwx stijl ';
$lang['755style'] = '755 stijl ';
$lang['quickmode'] = 'Snelle chmod (zoals 777)';
$lang['chmod'] = 'Wijzig permissies';
$lang['chmodselected'] = 'Wijzig permissies op geselecteerde bestanden';
$lang['chmodsuccess'] = 'Permissies gewijzigd';
$lang['chmodfailure'] = 'Permissies wijzigen mislukt';
$lang['chmodcancelled'] = 'Permissies wijzigen geannuleerd';
$lang['newuploadfailed'] = '%s bestand(en) is/zijn NIET ge&uuml;pload (of wellicht niet uitgepakt)';
$lang['newuploadsuccess'] = '%s bestand(en) is/zijn ge&uuml;pload (en indien aangevinkt ook uitgepakt)';
$lang['dirchmodfailmulti'] = 'Permissie wijzigen van deze map is mislukt, het kan echter wel zijn dat bepaalde bestanden wel gewijzigde rechten hebben gekregen.';
$lang['dirchmodsuccessmulti'] = 'Permissies wijzigen van de map en de inhoud is geslaagd';
$lang['dirchmodsuccess'] = 'Map permissies gewijzigd';
$lang['dirchmodfailure'] = 'Map permissies wijzigen mislukt';
$lang['dirnotemptyconfirm'] = 'Deze map is niet leeg. Weet u zeker dat deze verwijderd moet worden en alle inhoud, inclusief de submappen?';
$lang['dirtreedeletecancelled'] = 'Verwijdering van de map afgebroken';
$lang['imsure'] = 'Ik weet het zeker';
$lang['cancel'] = 'Annuleer';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Upload nieuwe bestanden:';
$lang['unpackafterupload'] = 'Probeer het bestand na upload, uit te pakken (alleen tgz en meeste zip-bestanden)?';
$lang['uploadsuccess'] = 'is ge&uuml;pload';
$lang['uploadfail'] = 'upload niet geslaagd';
$lang['unpacksuccess'] = 'is uitgepakt';
$lang['unpackfail'] = 'afgebroken met deze fout:';
$lang['packfileopenfail'] = 'Kon het ingepakte bestand niet openen om uit te pakken (niet-ondersteund formaat?)';
$lang['packfilewritefail'] = 'Kan het bestand %s niet openen om naar te schrijven';
$lang['afilecontainsillegalchars'] = 'Een bestandsnaam bevat niet toegestane karakters (&#039;,&quot;,+,*,\,/,&amp;,$). Upload is geannuleerd.';
$lang['currentpath'] = 'Huidig pad:';
$lang['newdirname'] = 'Maak nieuwe map aan:';
$lang['newdirsuccess'] = 'De map is aangemaakt';
$lang['newdirfail'] = 'Er is een fout opgetreden bij het aanmaken van de map';
$lang['direxists'] = 'De mapnaam bestaat al';
$lang['invalidnewdir'] = 'Naam van de nieuwe map geen karakters zoals /, \ en &#039;..&#039; bevatten';
$lang['filedateformat'] = 'm/d/J U:m:s';
$lang['iconsize'] = 'Pictogramgrootte';
$lang['smallicons'] = 'Kleine pictogrammen';
$lang['largeicons'] = 'Grote pictogrammen';
$lang['thousanddelimiter'] = 'Duizendtal scheidingsteken';
$lang['none'] = 'Geen';
$lang['space'] = 'ruimte';
$lang['showthumbnails'] = 'Toon miniaturen';
$lang['showthumbnailshelp'] = 'Activeren zorgt er voor dat er miniaturen worden getoond van de afbeeldingen en zal direct ook het miniatuur-bestand zelf verbergen. Deactiveren zorgt ervoor dat alle bestanden worden getoond.';
$lang['uploadfilesto'] = 'Upload bestanden naar: ';
$lang['uploadview'] = 'Upload bestanden';
$lang['uploadboxes'] = 'Aantal uploadvelden';
$lang['nothinguploaded'] = 'Niets ge&uuml;pload';
$lang['newunsupportedarchive'] = '%s heeft een niet ondersteund archief formaat';
$lang['uploadmethod'] = 'Upload-methode';
$lang['uploaderstandard'] = 'Standaard html invoermethode (staat uitpakken toe)';
$lang['enableadvanced'] = 'Sta gevorderdenmodus toe?';
$lang['advancedhelp'] = 'Geeft u toegang tot het gehele CMSMS bestandssysteem, niet alleen /uploads/ (indien toegestaan)';
$lang['showhiddenfileshelp'] = 'Alleen effectief in de gevorderenmodus';
$lang['showhiddenfiles'] = 'Toon verborgen bestanden';
$lang['settingsconfirmsingledelete'] = 'Bevestig verwijdering van een enkel bestand?';
$lang['settingssaved'] = 'Instellingen opgeslagen';
$lang['help'] = '		<h3>Wat doet het?</h3>
		<p>Deze module verzorgt een bestandsbeheer functionaliteit</p>
		<h3>Hoe gebruikt u het</h3>
		<p>Selecteer Bestandsbeheer in het Inhoudsmenu.</p>';
$lang['utma'] = '156861353.1335698708.1284586217.1294649577.1294650161.782';
$lang['utmz'] = '156861353.1294432973.744.60.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/bug/list/133';
$lang['qca'] = 'P0-1551306179-1284586216711';
$lang['utmb'] = '156861353.1.10.1294650161';
$lang['utmc'] = '156861353';
?>
